"""

@FileName: adb_tools.py
@Author: chenxiaodong
@CreatTime: 2020/9/14 16:23
@Descriptions: 

"""


class adb_tools:
    def __init__(self):
        """
        :param:
        :return:

        """
        pass

    def adb_kill_server(self):
        """
        :param:
        :return:

        """
        pass

    def adb_start_server(self):
        """
        :param:
        :return:

        """
        pass

    def adb_shell(self):
        """
        :param:
        :return:

        """
        pass

    def adb_connect(self):
        """
        :param:
        :return:

        """
        pass

    def adb_devices(self):
        """
        :param:
        :return:

        """
        pass

    def adb_install(self):
        """
        :param: 
        :return: 
        
        """
        pass

    def adb_uninstall(self):
        """
        :param:
        :return:

        """
        pass
