"""

@FileName: console_line_tools.py
@Author: chenxiaodong
@CreatTime: 2020/9/14 16:23
@Descriptions: 

"""


class console_line_tools:

    def __init__(self):
        """
        :param:
        :return:

        """
        pass
